@@ -6,9 +6,11 @@ use Test::More;
 use Test::Cukes::Feature;
 use Carp::Assert;
 
-our $VERSION = "0.02";
+our $VERSION = "0.04";
 our @EXPORT = qw(feature runtests Given When Then assert affirm should shouldnt);
 
+our @missing_steps = ();
+
 my $steps = {};
 my $feature = {};
 
@@ -22,40 +24,61 @@ sub feature {
 sub runtests {
     my $caller = caller;
     my $total_tests = 0;
-    for my $scenario (@{$feature->{$caller}->scenarios}) {
+    my @scenarios_of_caller = @{$feature->{$caller}->scenarios};
+
+    for my $scenario (@scenarios_of_caller) {
         $total_tests += @{$scenario->steps};
     }
 
     Test::More::plan(tests => $total_tests);
 
-    my $skip = 0;
-    my $skip_reason = "";
-    for my $scenario (@{$feature->{$caller}->scenarios}) {
-        my %steps = %{$steps->{$caller}};
+    for my $scenario (@scenarios_of_caller) {
+        my $skip = 0;
+        my $skip_reason = "";
+
+        my %steps = %{$steps->{$caller} ||{}};
+    SKIP:
         for my $step_text (@{$scenario->steps}) {
             my (undef, $step) = split " ", $step_text, 2;
+            Test::More::skip($step, 1) if $skip;
 
-        SKIP:
+            my $found_step = 0;
             while (my ($step_pattern, $cb) = each %steps) {
-                Test::More::skip($step, 1) if $skip;
-
                 if ($step =~ m/$step_pattern/) {
                     eval { $cb->(); };
                     Test::More::ok(!$@, $step_text);
 
                     if ($@) {
+                        Test::More::diag($@);
                         $skip = 1;
                         $skip_reason = "Failed: $step_text";
                     }
-                    next;
+
+                    $found_step = 1;
+                    last;
                 }
             }
+
+            unless($found_step) {
+                push @missing_steps, $step_text;
+            }
         }
     }
 
+    report_missing_steps();
+
     return 0;
 }
 
+sub report_missing_steps {
+    Test::More::note("There are missing step definitions, fill them in:");
+    for my $step_text (@missing_steps) {
+        my ($word, $text) = ($step_text =~ /^(Given|When|Then) (.+)$/);
+        my $msg = "\n$word qr/${text}/ => sub {\n    ...\n}\n";
+        Test::More::note($msg);
+    }
+}
+
 sub _add_step {
     my ($step, $cb) = @_;
     my $caller = caller;
